@@ -56,8 +56,13 @@ global AWS_REGION_NAME
 #Tomando variables del establecimiento de credenciales
 
 
-class CRTM (bucketName, accessKey, secretKey, regionName):
+class CRTM ():
     def __init__(self, bucketName, accessKey, secretKey, regionName):
+        self.bucketName = bucketName
+        self.accessKey = accessKey
+        self.secretKey = secretKey
+        self.regionName = regionName
+
         AWS_BUCKET_NAME = bucketName
         AWS_ACCESS_KEY = accessKey
         AWS_SECRET_KEY = secretKey
